Package: nftbart
Type: Package
Title: Nonparametric Failure Time Bayesian Additive Regression Trees
Version: 2.3
Date: 2025-12-02
Authors@R: c(person('Rodney', 'Sparapani', 
	   role=c('aut', 'cre'), email='rsparapa@mcw.edu'),
	   person('Robert', 'McCulloch', role='aut'),
  	   person('Matthew', 'Pratola', role='ctb'), 
	   person('Hugh', 'Chipman', role='ctb'))
Author: Rodney Sparapani [aut, cre],
  Robert McCulloch [aut],
  Matthew Pratola [ctb],
  Hugh Chipman [ctb]
Maintainer: Rodney Sparapani <rsparapa@mcw.edu>
Description: Nonparametric Failure Time (NFT) Bayesian Additive Regression Trees (BART): Time-to-event Machine Learning with Heteroskedastic Bayesian Additive Regression Trees (HBART) and Low Information Omnibus (LIO) Dirichlet Process Mixtures (DPM). An NFT BART model is of the form Y = mu + f(x) + sd(x) E where functions f and sd have BART and HBART priors, respectively, while E is a nonparametric error distribution due to a DPM LIO prior hierarchy. See the following for a description of the model at <doi:10.1111/biom.13857>.
License: GPL (>= 2)
Depends: R (>= 4.2.0), survival, nnet, lattice
Imports: Rcpp
LinkingTo: Rcpp
NeedsCompilation: yes
Packaged: 2025-12-02 19:35:08 UTC; rsparapa
Repository: CRAN
Date/Publication: 2025-12-03 08:00:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 04:20:11 UTC; unix
Archs: nftbart.so.dSYM
