useDynLib(nftbart, .registration=TRUE)
S3method(predict, nft)
S3method(predict, nft2)
S3method(predict, aftree)
##S3method(predict, nftmi)
##S3method(predict, nft2mi)
##export(mi.nft, mi.nft2)
export(nft, nft2)
export(CDimpute)
export(tsvs, tsvs2)
export(bMM, xicuts, Cindex)
##export(bMM, xicuts, Cindex, concordance)
##export(bartModelMatrix)
importFrom("nnet", class.ind)
importFrom("survival", survfit, Surv, survreg)
importFrom("Rcpp", evalCpp)
importFrom("stats", coef, cor, dnorm, pnorm, predict,
           quantile, rbeta, residuals, rnorm, sd, var)
importFrom("graphics", abline, lines, par, points, text)
importFrom("grDevices", dev.off, pdf)
importFrom("lattice", ltext, panel.number, panel.xyplot, xyplot) 
importFrom("utils", "str")
